==> eiffelstudio-18.01.10.1424.tar: F_code/C18/dy876.c <==
/*
 * Code for class DYNAMIC_CHAIN [CHARACTER_32]
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "dy876.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {DYNAMIC_CHAIN}.extendible */
EIF_BOOLEAN F650_4738 (EIF_REFERENCE Current)
{
	GTCX
	
	
	return (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
}

/* {DYNAMIC_CHAIN}.prunable */
EIF_BOOLEAN F650_4739 (EIF_REFERENCE Current)
{
	GTCX
	
	
	return (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
}

/* {DYNAMIC_CHAIN}.prune */
void F650_4745 (EIF_REFERENCE Current, EIF_CHARACTER_32 arg1)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R3093[Dtype(Current)-249])(Current, (EIF_REFERENCE) &arg1);
	if ((EIF_BOOLEAN) !F255_3266(Current)) {
		F702_5067(Current);
	}
	RTLE;
}

/* {DYNAMIC_CHAIN}.prune_all */
void F650_4748 (EIF_REFERENCE Current, EIF_CHARACTER_32 arg1)
{
	GTCX
	RTCDT;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	(FUNCTION_CAST(void, (EIF_REFERENCE)) R3087[dtype-273])(Current);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R3093[dtype-249])(Current, (EIF_REFERENCE) &arg1);
	for (;;) {
		if (F255_3266(Current)) break;
		F702_5067(Current);
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R3093[dtype-249])(Current, (EIF_REFERENCE) &arg1);
	}
	RTLE;
}

/* {DYNAMIC_CHAIN}.wipe_out */
void F650_4749 (EIF_REFERENCE Current)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	(FUNCTION_CAST(void, (EIF_REFERENCE)) R3087[Dtype(Current)-273])(Current);
	for (;;) {
		if (F362_3386(Current)) break;
		F702_5067(Current);
	}
	RTLE;
}

void EIF_Minit876 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.07.10.1981.tar: F_code/C18/dy876.c <==
/*
 * Code for class DYNAMIC_CHAIN [BOOLEAN]
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "dy876.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {DYNAMIC_CHAIN}.extendible */
EIF_BOOLEAN F650_4739 (EIF_REFERENCE Current)
{
	GTCX
	
	
	return (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
}

/* {DYNAMIC_CHAIN}.prunable */
EIF_BOOLEAN F650_4740 (EIF_REFERENCE Current)
{
	GTCX
	
	
	return (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
}

/* {DYNAMIC_CHAIN}.prune */
void F650_4746 (EIF_REFERENCE Current, EIF_BOOLEAN arg1)
{
	GTCX
	RTCDT;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R3093[dtype-249])(Current, (EIF_REFERENCE) &arg1);
	if ((EIF_BOOLEAN) !F255_3266(Current)) {
		(FUNCTION_CAST(void, (EIF_REFERENCE)) R3136[dtype-353])(Current);
	}
	RTLE;
}

/* {DYNAMIC_CHAIN}.prune_all */
void F650_4749 (EIF_REFERENCE Current, EIF_BOOLEAN arg1)
{
	GTCX
	RTCDT;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	(FUNCTION_CAST(void, (EIF_REFERENCE)) R3087[dtype-273])(Current);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R3093[dtype-249])(Current, (EIF_REFERENCE) &arg1);
	for (;;) {
		if (F255_3266(Current)) break;
		(FUNCTION_CAST(void, (EIF_REFERENCE)) R3136[dtype-353])(Current);
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R3093[dtype-249])(Current, (EIF_REFERENCE) &arg1);
	}
	RTLE;
}

/* {DYNAMIC_CHAIN}.wipe_out */
void F650_4750 (EIF_REFERENCE Current)
{
	GTCX
	RTCDT;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	(FUNCTION_CAST(void, (EIF_REFERENCE)) R3087[dtype-273])(Current);
	for (;;) {
		if (F361_3386(Current)) break;
		(FUNCTION_CAST(void, (EIF_REFERENCE)) R3136[dtype-353])(Current);
	}
	RTLE;
}

void EIF_Minit876 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
